# Adguard with Tailscale Integration

![Adguard with Tailscale](https://github.com/AdguardTeam/AdGuardHome/raw/master/doc/adguard_home_darkmode.svg "AdGuard Home")

This project sets up a Adguard instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your Adguard instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-adguard/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/  # Persistent Tailscale state
│   └── config/         # Tailscale configuration files
└── adguard/
    ├── conf/         # adguard configuration files
    └── work/         # adguard state files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-adguard
   cd ts-adguard
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data adguard/conf adguard/work
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations
        - CAUTION: Changing `"${TS_CERT_DOMAIN}:443": false` to `true` will expose the service to the internet

4. Configure Adguard **OPTIONAL**
    - See https://adguard-dns.io/kb/adguard-home/getting-started/ for configuration options

5. Start the Services
    ```bash
    docker compose up -d
    ```

6. Wait for Certificate to propagate [~2m] 

7. Login

## Services

### adguard-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: adguard-ts
- Hostname: adguard
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### adguard

- Depends on adguard-ts service

## Usage

- After starting the services your service should be available via tailnet at `https://adguard.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://adguard.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs adguard-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 3000:3000
    ```
- Stopping the Services
    ```bash
    docker compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs adguard-ts
    docker logs adguard
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting

## Notes
- The Adguard service uses the Tailscale service's network stack via `network_mode: service:adguard-ts`
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - Adguard documentation: https://adguard-dns.io/kb/adguard-home/getting-started/
    - Adguard repository: https://github.com/AdguardTeam/AdGuardHome